@@ -1633,6 +1633,8 @@ reload_systemd_sessions (ActUserManager *manager)
         int         i;
         char       **sessions;
         GHashTable  *systemd_sessions;
+        char        *state;
+        gboolean     is_closing;
 
 
         res = sd_get_sessions (&sessions);
@@ -1647,6 +1649,20 @@ reload_systemd_sessions (ActUserManager *manager)
 
         if (sessions != NULL) {
                 for (i = 0; sessions[i] != NULL; i ++) {
+                        res = sd_session_get_state (sessions[i], &state);
+
+                        if (res < 0) {
+                                g_debug ("Failed to determine state of session %s: %s", sessions[i], strerror (-res));
+                                continue;
+                        }
+
+                        is_closing = g_strcmp0 (state, "closing") == 0;
+                        free (state);
+
+                        if (is_closing) {
+                                continue;
+                        }
+
                         g_hash_table_insert (systemd_sessions,
                                              sessions[i], NULL);
                 }
@@ -2721,7 +2737,9 @@ act_user_manager_delete_user (ActUserManager  *manager,
 
         g_debug ("ActUserManager: Deleting user '%s' (uid %ld)", act_user_get_user_name (user), (long) act_user_get_uid (user));
 
-        g_assert (manager->priv->accounts_proxy != NULL);
+        g_return_val_if_fail (ACT_IS_USER_MANAGER (manager), FALSE);
+        g_return_val_if_fail (ACT_IS_USER (user), FALSE);
+        g_return_val_if_fail (manager->priv->accounts_proxy != NULL, FALSE);
 
         local_error = NULL;
         if (!accounts_accounts_call_delete_user_sync (manager->priv->accounts_proxy,
