@@ -55,6 +55,7 @@ enum {
         PROP_LOCKED,
         PROP_AUTOMATIC_LOGIN,
         PROP_SYSTEM_ACCOUNT,
+        PROP_LOCAL_ACCOUNT,
         PROP_LOGIN_FREQUENCY,
         PROP_ICON_FILE,
         PROP_LANGUAGE,
@@ -98,6 +99,7 @@ struct _ActUser {
         guint           locked : 1;
         guint           automatic_login : 1;
         guint           system_account : 1;
+        guint           local_account : 1;
 };
 
 struct _ActUserClass
@@ -169,23 +171,6 @@ act_user_get_num_sessions (ActUser    *user)
         return g_list_length (user->sessions);
 }
 
-static void
-act_user_set_property (GObject      *object,
-                       guint         param_id,
-                       const GValue *value,
-                       GParamSpec   *pspec)
-{
-        ActUser *user;
-
-        user = ACT_USER (object);
-
-        switch (param_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-                break;
-        }
-}
-
 static void
 act_user_get_property (GObject    *object,
                        guint       param_id,
@@ -248,6 +233,9 @@ act_user_get_property (GObject    *object,
         case PROP_SYSTEM_ACCOUNT:
                 g_value_set_boolean (value, user->system_account);
                 break;
+        case PROP_LOCAL_ACCOUNT:
+                g_value_set_boolean (value, user->local_account);
+                break;
         case PROP_IS_LOADED:
                 g_value_set_boolean (value, user->is_loaded);
                 break;
@@ -266,7 +254,6 @@ act_user_class_init (ActUserClass *class)
         gobject_class = G_OBJECT_CLASS (class);
 
         gobject_class->finalize = act_user_finalize;
-        gobject_class->set_property = act_user_set_property;
         gobject_class->get_property = act_user_get_property;
 
         g_object_class_install_property (gobject_class,
@@ -399,6 +386,14 @@ act_user_class_init (ActUserClass *class)
                                                                FALSE,
                                                                G_PARAM_READABLE));
 
+        g_object_class_install_property (gobject_class,
+                                         PROP_LOCAL_ACCOUNT,
+                                         g_param_spec_boolean ("local-account",
+                                                               "Local Account",
+                                                               "Local Account",
+                                                               FALSE,
+                                                               G_PARAM_READABLE));
+
         g_object_class_install_property (gobject_class,
                                          PROP_SYSTEM_ACCOUNT,
                                          g_param_spec_boolean ("system-account",
@@ -803,6 +798,22 @@ act_user_is_system_account (ActUser *user)
         return user->system_account;
 }
 
+/**
+ * act_user_is_local_account:
+ * @user: the user object to examine.
+ *
+ * Retrieves whether the user is a local account or not.
+ *
+ * Returns: (transfer none): %TRUE if the user is local
+ **/
+gboolean
+act_user_is_local_account (ActUser   *user)
+{
+        g_return_val_if_fail (ACT_IS_USER (user), FALSE);
+
+        return user->local_account;
+}
+
 /**
  * act_user_get_icon_file:
  * @user: a #ActUser
@@ -1009,6 +1020,14 @@ collect_props (const gchar *key,
                         user->system_account = new_system_account_state;
                         g_object_notify (G_OBJECT (user), "system-account");
                 }
+        } else if (strcmp (key, "LocalAccount") == 0) {
+                gboolean new_local;
+
+                new_local = g_variant_get_boolean (value);
+                if (user->local_account != new_local) {
+                        user->local_account = new_local;
+                        g_object_notify (G_OBJECT (user), "local-account");
+                }
         } else if (strcmp (key, "LoginFrequency") == 0) {
                 int new_login_frequency;
 
@@ -1102,7 +1121,7 @@ on_get_all_finished (GObject        *object,
         g_signal_emit (user, signals[CHANGED], 0);
 }
 
-static gboolean
+static void
 update_info (ActUser *user)
 {
         g_assert (G_IS_DBUS_PROXY (user->object_proxy));
@@ -1121,10 +1140,6 @@ update_info (ActUser *user)
                            user->get_all_call,
                            on_get_all_finished,
                            user);
-        return TRUE;
-
-failed:
-        return FALSE;
 }
 
 static void
@@ -1185,9 +1200,7 @@ _act_user_update_from_object_path (ActUser    *user,
                 return;
         }
 
-        if (!update_info (user)) {
-                g_warning ("Couldn't update info for user with object path %s", object_path);
-        }
+       update_info (user);
 }
 
 void
